import {Component, OnInit, ViewChild} from '@angular/core';
import {OaipmhValidatorService} from "../../../services/oaipmh-validator.service";
import {Status} from "../../entities/RuleInfo";
import {JobResult, Progress} from "../../entities/JobResult";
import {ActivatedRoute} from "@angular/router";
import {Breadcrumb} from "../../../shared/utils/breadcrumbs/breadcrumbs.component";
import {Subscriber} from "rxjs";

@Component({
  selector: 'app-oaipmh-history',
  templateUrl: './oaipmh-history.component.html',
  styleUrls: ['./oaipmh-history.component.less']
})
export class OaipmhHistoryComponent implements OnInit {
  public result: JobResult;
  public jobId: string = "";
  public breadcrumbs: Breadcrumb[] = [{name: 'home', route: '/'}, {name: 'Validator\'s History'}];
  protected readonly Progress = Progress;

  subscriptions = [];

  constructor(private route: ActivatedRoute, private validator: OaipmhValidatorService) {}

  ngOnInit(): void {
    this.subscriptions.push(this.route.queryParams.subscribe(params => {
      this.jobId = params['jobId'];
      this.result = null;
      if(!this.jobId) {
        this.jobId = "825";
      }
        this.getJobResult();

    }));
  }

  ngOnDestroy() {
    this.subscriptions.forEach(subscription => {
      if (subscription instanceof Subscriber) {
        subscription.unsubscribe();
      }
    });
  }

  public getJobResult() {
    this.validator.getJobResult(this.jobId).subscribe(
      (result: JobResult) => {
        this.result = result;
      }
    );
  }

  protected readonly Status = Status;
}
